@@ -5,10 +5,7 @@
 #importing required modules and dependencies
 import json
 import numpy as np
-import pandas as pd
 import os
-import matplotlib.pyplot as plt
-import numpy as np
 from sklearn.preprocessing import OneHotEncoder, LabelEncoder
 import sys, copy, re
 import requests
@@ -19,7 +16,10 @@ import urllib.request as request
 from contextlib import closing
 from difflib import get_close_matches
 
+#global vars
 DATA_DIR = 'data'
+AAINDEX_FILENAME = 'aaindex1'
+DOWNLOAD_USING = 'ftp'
 
 class AAIndex():
     """
@@ -31,6 +31,7 @@ class AAIndex():
     (http://www.genome.jp/aaindex/).
     Some of the parsing functionality is patrially inspired off the AAIndex1 parser
     by harmslab: https://github.com/harmslab/hops/blob/master/hops/features/data/util/aaindex2json.py
+
     Data format of AAI1:
     ************************************************************************
     *                                                                      *
@@ -65,13 +66,6 @@ class AAIndex():
         4.35    4.38    4.75    4.76    4.65    4.37    4.29    3.97    4.63    3.95
         4.17    4.36    4.52    4.66    4.44    4.50    4.35    4.70    4.60    3.95
     --------------------------------------------------------------------------------
-    Attributes
-    ----------
-    :aaindex_filename : str (default = 'aaindex1')
-        local filename of aaindex1 file that class will import the database
-        from in the data directory, default value of 'aaindex1' is reccomended.
-    :download_using : str (default = "ftp")
-        decide to download AAI database using ftp or https, ftp used by default.
 
     Methods
     -------
@@ -93,12 +87,12 @@ class AAIndex():
         return list of all descriptions for all records in AAI database.
     get_record_from_desc():
         return AAI record from its description.
-    get_values_from_record(code):
-        return amino acid index values for AAI record usings its accession number.
     get_ref_from_record():
         return references for AAI record.
     get_category_from_record():
         return category of AAI index record.
+    __getitem__():
+        access full aaindex record using its record code.
 
     References
     ----------
@@ -113,27 +107,25 @@ class AAIndex():
     [4]: Kawashima, S. and Kanehisa, M.;  AAindex: amino acid index
         database.  Nucleic Acids Res. 28, 374 (2000).
     """
-    def __init__(self, aaindex_filename='aaindex1', download_using='ftp'):
+    def __init__(self):
 
-        self.aaindex_filename = aaindex_filename
-        self.download_using = download_using
-        self.pySAR_module_path = os.path.dirname(os.path.abspath(sys.modules[self.__module__].__file__))
+        self.aaindex_module_path = os.path.dirname(os.path.abspath(sys.modules[self.__module__].__file__))
 
         #download AAI database using ftp or https
-        if self.download_using=='ftp':
+        if DOWNLOAD_USING =='ftp':
             self.url = "ftp://ftp.genome.jp/pub/db/community/aaindex/aaindex1"
-        elif self.download_using=='http' or self.download_using=='https':
+        elif DOWNLOAD_USING =='http' or DOWNLOAD_USING =='https':
             self.url = "https://www.genome.jp/ftp/db/community/aaindex/aaindex1"
         else:
             self.url = "ftp://ftp.genome.jp/pub/db/community/aaindex/aaindex1"
 
         #if AAIndex database not found in data directory then call download method
-        if not (os.path.isfile(os.path.join(self.pySAR_module_path, DATA_DIR, self.aaindex_filename))):
+        if not (os.path.isfile(os.path.join(self.aaindex_module_path, DATA_DIR, AAINDEX_FILENAME))):
             self.download_aaindex()
 
         #if parsed json of AAIndex already in file then read it and return 
-        if (os.path.isfile(os.path.join(self.pySAR_module_path, DATA_DIR, self.aaindex_filename + '.json'))):
-            with open(os.path.join(self.pySAR_module_path, DATA_DIR, self.aaindex_filename +'.json')) as aai_json:
+        if (os.path.isfile(os.path.join(self.aaindex_module_path, DATA_DIR, AAINDEX_FILENAME + '.json'))):
+            with open(os.path.join(self.aaindex_module_path, DATA_DIR, AAINDEX_FILENAME +'.json')) as aai_json:
                 self.aaindex_json = json.load(aai_json)
         else:
             #parse AAIndex database file into JSON format
@@ -147,7 +139,8 @@ class AAIndex():
         Parse AAI database into JSON format. Each AAI record will be indexed by
         its feature code/index code, and will be in the format as shown in the
         docstring above. The file will be stored in a json file called according
-        to (self.aaindex_filename) variable.
+        to (AAINDEX_FILENAME) variable.
+
         Returns
         -------
         :aaindex_json : dict
@@ -166,10 +159,10 @@ class AAIndex():
 
         #open AAI file for reading and parsing, by default it should be stored in DATA_DIR
         try:
-            tmp_filepath = os.path.join(self.pySAR_module_path, DATA_DIR, self.aaindex_filename)
+            tmp_filepath = os.path.join(self.aaindex_module_path, DATA_DIR, AAINDEX_FILENAME)
             f = open(tmp_filepath,'r')
         except IOError:
-            print('Error opening file, check filename = {} and is stored in {} directory.'.format(self.aaindex_filename, DATA_DIR))
+            print('Error opening file, check filename = {} and is stored in {} directory.'.format(AAINDEX_FILENAME, DATA_DIR))
 
         #read lines of file
         lines = f.readlines()
@@ -273,7 +266,7 @@ class AAIndex():
                     aaindex_json[index]['values'][val] = 0
 
         #save parsed dictionary into JSON format to DATA_DIR
-        with open((os.path.join(self.pySAR_module_path, DATA_DIR, self.aaindex_filename + '.json')),'w') as output_F:
+        with open((os.path.join(self.aaindex_module_path, DATA_DIR, AAINDEX_FILENAME + '.json')),'w') as output_F:
           json.dump(aaindex_json, output_F, indent=4, sort_keys=True)
 
         return aaindex_json
@@ -284,23 +277,24 @@ class AAIndex():
         the dedicated FTP or HTTPS server from https://www.genome.jp/aaindex/.
         FTP is the default method used for downloading the database with the URL:
         "ftp://ftp.genome.jp/pub/db/community/aaindex/aaindex1". If you want to
-        download by https, set the 'download_using' instance variable to 'https'. pySAR
+        download by https, set the 'DOWNLOAD_USING' variable to 'https'. The class
         looks for the AAI database and its parsed JSON form in the 'data' directory, an
         error will throw if not found.
+
         Parameters
         ----------
         :save_dir : str (default = DATA_DIR)
             Directory to save the AAI database to. By default it wil be stored in
             the global var DATA_DIR = 'data'. Parameter has to point to a directory
-            within the pySAR directory or there will be an error on instantiation 
+            within the aaindex directory or there will be an error on instantiation 
             of the class. 
         """
         #fetch AAI database from URL if not present in DATA_DIR
         try:
-            if not(os.path.isfile(os.path.join(self.pySAR_module_path, save_dir, self.aaindex_filename))):
+            if not(os.path.isfile(os.path.join(self.aaindex_module_path, save_dir, AAINDEX_FILENAME))):
                 try:
                     with closing(request.urlopen(self.url)) as r:
-                        with open((os.path.join(self.pySAR_module_path, save_dir, self.aaindex_filename)), 'wb') as f:
+                        with open((os.path.join(self.aaindex_module_path, save_dir, AAINDEX_FILENAME)), 'wb') as f:
                             shutil.copyfileobj(r, f)
                     print('AAIndex1 successfully downloaded.')
                 except requests.exceptions.RequestException:
@@ -314,12 +308,14 @@ class AAIndex():
         """
         Parse category file which maps each AAI record in the databse into 1 of 8 categories.
         Category file and parsing code inspired from: https://github.com/harmslab/hops. 
+
         Parameters
         ----------
         :aaindex_category_file : str
             Name of category file to parse (default is "aaindex_to_category.txt"). If parameter
             is a file name then it will be imported from the 'data' directory by default, else
             it will be imported from its full path.
+
         Returns
         -------
         :aaindex_category : dict
@@ -334,7 +330,7 @@ class AAIndex():
                     .format(aaindex_category_file))
         else:
             try:
-                f = open((os.path.join(self.pySAR_module_path, DATA_DIR, aaindex_category_file)),'r')
+                f = open((os.path.join(self.aaindex_module_path, DATA_DIR, aaindex_category_file)),'r')
             except IOError:
                 print('Error opening AAIndex1 category file, check {} in {} directory'
                     .format(aaindex_category_file, DATA_DIR))
@@ -345,7 +341,7 @@ class AAIndex():
         #open new file in data directory to store parsed category file
         f.seek(0)
         category_output_file = "aaindex_categories.txt"
-        f_out = open((os.path.join(self.pySAR_module_path, DATA_DIR, category_output_file)), "w")
+        f_out = open((os.path.join(self.aaindex_module_path, DATA_DIR, category_output_file)), "w")
 
         #lines starting with '#' are file metadata so don't write these to parsed output file
         for line in f.readlines():
@@ -356,7 +352,7 @@ class AAIndex():
         f_out.close()
 
         #open parsed category file for reading
-        with open(os.path.join(self.pySAR_module_path, DATA_DIR, category_output_file)) as f_out:
+        with open(os.path.join(self.aaindex_module_path, DATA_DIR, category_output_file)) as f_out:
             reader = csv.reader(f_out, delimiter="\t")
             d = list(reader)
 
@@ -364,10 +360,10 @@ class AAIndex():
 
         #iterate through all lines in parsed file and store AAI indices as keys
         #  in the output dict and their respective categories as the values of dict
-        for i in range(0,len(d)):
-          for j in range(0,len(d[i])):
+        for i in range(0, len(d)):
+          for j in range(0, len(d[i])):
             category_substring = d[i][1].strip()
-            category_substring = category_substring.split(" ",1)
+            category_substring = category_substring.split(" ", 1)
             aaindex_category[d[i][0]] = category_substring[0]
 
         self.categories = aaindex_category
@@ -376,6 +372,7 @@ class AAIndex():
         """
         Return list of all indices, their description and associated categories from 
         parsed aaindex_categories.txt file created from parse_categories() function.
+
         Parameters
         ----------
         :category_file : str
@@ -387,12 +384,12 @@ class AAIndex():
             Dictionary that maps each AAI record into 1 of 8 categories.
         """
         #if parsed categories file doesn't exist in DATA_DIR then call function
-        if not (os.path.isfile(os.path.join(self.pySAR_module_path, DATA_DIR, category_file))):
+        if not (os.path.isfile(os.path.join(self.aaindex_module_path, DATA_DIR, category_file))):
             self.parse_categories()
 
         #read categories file and its content
         try:
-            with open(os.path.join(self.pySAR_module_path, DATA_DIR, category_file)) as f_out:
+            with open(os.path.join(self.aaindex_module_path, DATA_DIR, category_file)) as f_out:
                 reader = csv.reader(f_out, delimiter="\t")
                 d = list(reader)
         except IOError:
@@ -402,10 +399,10 @@ class AAIndex():
 
         #iterate through all lines in parsed file and store AAI indices as keys
         #   in the output dict and their respective categories as the values of dict
-        for i in range(0,len(d)):
-          for j in range(0,len(d[i])):
+        for i in range(0, len(d)):
+          for j in range(0, len(d[i])):
             category_substring = d[i][1].strip()
-            category_substring = category_substring.split(" ",1)
+            category_substring = category_substring.split(" ", 1)
             aaindex_category[d[i][0]] = category_substring[0]
 
         return aaindex_category
@@ -455,6 +452,7 @@ class AAIndex():
         :all_matches : bool (default=false)
             if set to true, all found matches in database returned else if false only the
             first found match is returned.
+
         Returns
         -------
         :matches : list(dict)
@@ -499,7 +497,7 @@ class AAIndex():
         Returns
         -------
         :amino_acids : list
-            List of all 20 canoniocal amino acid letters as found in each record
+            List of all 20 canonical amino acid letters as found in each record
             of the AAI database.
         """
         amino_acids = list(self.aaindex_json[list(self.aaindex_json.keys())[0]]["values"].keys())
@@ -559,6 +557,7 @@ class AAIndex():
     def get_record_names(self):
         """
         Return a list of all index descriptions for all records in the AAI database.
+
         Returns
         -------
         :desc : list
@@ -582,14 +581,6 @@ class AAIndex():
     def url(self, value):
         self._url = value
 
-    @property
-    def aaindex_filename(self):
-        return self._aaindex_filename
-
-    @aaindex_filename.setter
-    def aaindex_filename(self, value):
-        self._aaindex_filename = value
-
     @property
     def categories(self):
         return self._categories
@@ -601,24 +592,27 @@ class AAIndex():
 ################################################################################
 
     def __repr__(self):
-        return (json.dumps(self.aaindex_json, indent=4, sort_keys=True))
+        return "<AAIndex: {}>".format(self)
 
     def __sizeof__(self):
         """ Return size of AAI database file """
-        return os.path.getsize(os.path.isfile(os.path.join(DATA_DIR, self.aaindex_filename)))
+        return os.path.getsize(os.path.isfile(os.path.join(DATA_DIR, AAINDEX_FILENAME)))
 
     def __getitem__(self, record_code):
         """
         Return full AAI database record details from its feature/index code/Accession number by
-        making the whole database subscriptable
+        making the whole database subscriptable.
+
         Parameters
         ----------
         :record_code : str
             AAI database record feature index/Accession number.
+
         Returns
         -------
         :record : dict
             dict of AAI database record.
+
         Usage
         -----
             aaindex = AAIndex()
@@ -642,4 +636,5 @@ class AAIndex():
 
 aaindex = AAIndex()
 
-# get_ref_from_record
\ No newline at end of file
+# get_ref_from_record()
+# get_values_from_record
\ No newline at end of file
